==> fantacalciobazar_0.3.tar.gz: fantacalciobazar/messaggi.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################

include("dati/head.php");

include("controlla_pass.php");
if ($pass_errata != "SI") {


if ($aggiungi_messaggio) {
$nuovo_messaggio = ereg_replace("
","",$nuovo_messaggio);
$nuovo_messaggio = stripslashes($nuovo_messaggio);
$file_messaggi = fopen("dati/messaggi.txt","a+");
flock($file_messaggi,2);
fwrite($file_messaggi,$nome_utente."#@?".$nuovo_messaggio."
");
flock($file_messaggi,3);
fclose($file_messaggi);
} # fine if ($aggiungi_messaggio)


echo "
<center><font size=+2>Messaggi</font></center>";

$messaggi = @file("dati/messaggi.txt");
$num_messaggi = count($messaggi);
if ($tutti_i_messaggi == "SI") $num_iniziale = 0;
else $num_iniziale = $num_messaggi - 25;
if ($num_iniziale < 0) $num_iniziale = 0;
for ($num1 = $num_iniziale ; $num1 < $num_messaggi ; $num1++) {
$messaggio = explode("#@?",$messaggi[$num1]);
$nome = $messaggio[0];
$messaggio = $messaggio[1];
echo "<font color=\"red\">$nome</font>: $messaggio<br>";
} # fine for $num1

echo "<center>";
if ($tutti_i_messaggi == "SI") {
echo "<a href=\"messaggi.php?tutti_i_messaggi=NO&nome_utente=$nome_utente&pass_fornita=$pass_fornita\">
<font size=-1>ultimi 25 messaggi</font></a>";
} # fine if ($tutti_i_messaggi == "SI")
else {
echo "<a href=\"messaggi.php?tutti_i_messaggi=SI&nome_utente=$nome_utente&pass_fornita=$pass_fornita\">
<font size=-1>archivio messaggi</font></a>";
} # fine else if ($tutti_i_messaggi == "SI")
echo "</center>";

echo "<table><tr>
<form method=\"post\" action=\"messaggi.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<td><textarea name=\"nuovo_messaggio\" rows=4 cols=50 wrap=\"virtual\"></textarea></td>
<td><input type=\"submit\" name=\"aggiungi_messaggio\" value=\"Aggiungi\"></td>
</form>
<form method=\"post\" action=\"messaggi.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"nome_squadra\" value=\"$nome_utente\">
<td><input type=\"submit\" name=\"ricarica\" value=\"Ricarica\"></td>
</form></tr></table>";

echo "<center><form method=\"post\" action=\"mercato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"nome_squadra\" value=\"$nome_utente\">
<input type=\"submit\" name=\"torna_mercato\" value=\"Torna al mercato\">
</form></center>";



} # fine if ($pass_errata != "SI")

include("dati/foot.php");
?>

==> fantacalciobazar_0.4.tar.gz: fantacalciobazar/messaggi.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################


include("controlla_pass.php");
include("$percorso_cartella_dati/head.php");
if ($pass_errata != "SI") {


if ($aggiungi_messaggio) {
$nuovo_messaggio = ereg_replace("
","",$nuovo_messaggio);
$nuovo_messaggio = stripslashes($nuovo_messaggio);
$file_messaggi = fopen("$percorso_cartella_dati/messaggi.txt","a+");
flock($file_messaggi,2);
fwrite($file_messaggi,$nome_utente."#@?".$nuovo_messaggio."
");
flock($file_messaggi,3);
fclose($file_messaggi);
} # fine if ($aggiungi_messaggio)


echo "
<center><font size=+2>Messaggi</font></center>";

$messaggi = @file("$percorso_cartella_dati/messaggi.txt");
$num_messaggi = count($messaggi);
if ($tutti_i_messaggi == "SI") $num_iniziale = 0;
else $num_iniziale = $num_messaggi - 25;
if ($num_iniziale < 0) $num_iniziale = 0;
for ($num1 = $num_iniziale ; $num1 < $num_messaggi ; $num1++) {
$messaggio = explode("#@?",$messaggi[$num1]);
$nome = $messaggio[0];
$messaggio = $messaggio[1];
echo "<font color=\"red\">$nome</font>: $messaggio<br>";
} # fine for $num1

echo "<center>";
if ($tutti_i_messaggi == "SI") {
echo "<a href=\"messaggi.php?tutti_i_messaggi=NO&nome_utente=$nome_utente&pass_fornita=$pass_fornita\">
<font size=-1>ultimi 25 messaggi</font></a>";
} # fine if ($tutti_i_messaggi == "SI")
else {
echo "<a href=\"messaggi.php?tutti_i_messaggi=SI&nome_utente=$nome_utente&pass_fornita=$pass_fornita\">
<font size=-1>archivio messaggi</font></a>";
} # fine else if ($tutti_i_messaggi == "SI")
echo "</center>";

echo "<table><tr>
<form method=\"post\" action=\"messaggi.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<td><textarea name=\"nuovo_messaggio\" rows=4 cols=50 wrap=\"virtual\"></textarea></td>
<td><input type=\"submit\" name=\"aggiungi_messaggio\" value=\"Aggiungi\"></td>
</form>
<form method=\"post\" action=\"messaggi.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"nome_squadra\" value=\"$nome_utente\">
<td><input type=\"submit\" name=\"ricarica\" value=\"Ricarica\"></td>
</form></tr></table>";

echo "<center><form method=\"post\" action=\"mercato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"nome_squadra\" value=\"$nome_utente\">
<input type=\"submit\" name=\"torna_mercato\" value=\"Torna al mercato\">
</form></center>";



} # fine if ($pass_errata != "SI")

include("$percorso_cartella_dati/foot.php");
?>
